.. _v1:

===============
CouchDB 1.x API
===============

Server
======

.. autoclass:: aiocouchdb.v1.server.Server
  :members:

Configuration
-------------

.. autoclass:: aiocouchdb.v1.config.ServerConfig
  :members:

Session
-------

.. autoclass:: aiocouchdb.v1.session.Session
  :members:

Database
========

.. autoclass:: aiocouchdb.v1.database.Database
  :members:

.. autoclass:: aiocouchdb.v1.authdb.AuthDatabase
  :members:

Security
--------

.. autoclass:: aiocouchdb.v1.security.DatabaseSecurity
  :members:

Document
========

.. autoclass:: aiocouchdb.v1.document.Document
  :members:

.. autoclass:: aiocouchdb.v1.authdb.UserDocument
  :members:

.. autoclass:: aiocouchdb.v1.document.DocAttachmentsMultipartReader
  :members:

.. autoclass:: aiocouchdb.v1.document.OpenRevsMultipartReader
  :members:

Design Document
===============

.. autoclass:: aiocouchdb.v1.designdoc.DesignDocument
  :members:

Attachment
==========

.. autoclass:: aiocouchdb.v1.attachment.Attachment
  :members:

.. autoclass:: aiocouchdb.v1.attachment.AttachmentReader
  :members:
